@@ -33,6 +33,7 @@ use strict;
 use warnings;
 # use bytes;
 use re 'taint';
+use version 0.77;
 
 our ( $EXIT_STATUS, $WARNINGS );
 
@@ -124,6 +125,14 @@ our @OPTIONAL_MODULES = (
   desc => 'Used to check DNS Sender Policy Framework (SPF) records to fight email
   address forgery and make it easier to identify spams.',
 },
+{
+  module => 'GeoIP2::Database::Reader',
+  version => 0,
+  desc => 'Used by the RelayCountry plugin (not enabled by default) to
+  determine the domain country codes of each relay in the path of an email. 
+  Also used by the URILocalBL plugin (not enabled by default) to provide ISP
+  and Country code based filtering.',
+},
 {
   module => 'Geo::IP',
   version => 0,
@@ -131,6 +140,14 @@ our @OPTIONAL_MODULES = (
   the domain country codes of each relay in the path of an email.  Also used by 
   the URILocalBL plugin to provide ISP and Country code based filtering.',
 },
+{
+  module => 'IP::Country::DB_File',
+  version => 0,
+  desc => 'Used by the RelayCountry plugin (not enabled by default) to
+  determine the domain country codes of each relay in the path of an email. 
+  Also used by the URILocalBL plugin (not enabled by default) to provide
+  Country code based filtering.',
+},
 {
   module => 'Net::CIDR::Lite',
   version => 0,
@@ -182,7 +199,7 @@ our @OPTIONAL_MODULES = (
   spamd (the --ssl option to spamd), you need to install this
   module. (You will need the OpenSSL libraries and use the
   ENABLE_SSL="yes" argument to Makefile.PL to build and run an SSL
-  compatibile spamc.)',
+  compatible spamc.)',
 },
 {
   module => 'Compress::Zlib',
@@ -263,6 +280,18 @@ our @OPTIONAL_MODULES = (
   desc => 'BSD::Resource provides BSD process resource limit and priority 
   functions.  It is used by the optional ResourceLimits Plugin.',
 },
+{
+  module => 'Archive::Zip',
+  version => 0,
+  desc => 'Archive::Zip provides an interface to ZIP archive files.
+  It is used by the optional OLEVBMacro Plugin.',
+},
+{
+  module => 'IO::String',
+  version => 0,
+  desc => 'IO::String emulates file interface for in-core strings.
+  It is used by the optional OLEVBMacro Plugin.',
+},
 );
 
 our @BINARIES = ();
@@ -346,15 +375,17 @@ sub debug_diagnostics {
 #   sub Net::Ident::_export_hooks;
 # ';
 
-  foreach my $moddef (@MODULES, @OPTIONAL_MODULES) {
+  my $prefix = '';
+  foreach my $moddef (@MODULES, 'optional', @OPTIONAL_MODULES) {
+    if ($moddef eq 'optional') { $prefix = 'optional '; next; }
     my $module = $moddef->{module};
     my $modver;
     if (eval ' require '.$module.'; $modver = $'.$module.'::VERSION; 1;')
     {
       $modver ||= '(undef)';
-      $out .= "module installed: $module, version $modver\n";
+      $out .= "${prefix}module installed: $module, version $modver\n";
     } else {
-      $out .= "module not installed: $module ('require' failed)\n";
+      $out .= "${prefix}module not installed: $module ('require' failed)\n";
     }
   }
   return $out;
@@ -624,7 +655,7 @@ sub try_module {
   if ($installed) {
     eval { $module_version = $moddef->{module}->VERSION };  # wrap just in case
     if (!$recommended_version ||
-        ($module_version && $module_version >= $recommended_version)) {
+        ($module_version && version->parse($module_version) >= version->parse($recommended_version))) {
       $version_meets_recommended = 1;
     }
     $module_version = '' if !defined $module_version;
